==> haskell-polyparse-1.12.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12.1
id: polyparse-1.12.1-FeZxex5koKh2BIaglzjzIj
key: polyparse-1.12.1-FeZxex5koKh2BIaglzjzIj
license: LicenseRef-LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
author: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    This version, 1.12.1 is a Non-Maintainer Upload (NMU). Report issues to the Hackage Trustees issue tracker.
    .
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
abi: fc07f3f4a99f9d66704f12b8240cbdfb
exposed: True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text
import-dirs: /usr/lib/ghc-8.6.4/site-local/polyparse-1.12.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/polyparse-1.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/polyparse-1.12.1
hs-libraries: HSpolyparse-1.12.1-FeZxex5koKh2BIaglzjzIj
depends:
    base-4.12.0.0 bytestring-0.10.8.2 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.12-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: polyparse
version: 1.12
id: polyparse-1.12-9D0YnY3UMon43vdSjbfwCd
key: polyparse-1.12-9D0YnY3UMon43vdSjbfwCd
license: LGPL
copyright: (c) 2006-2016 Malcolm Wallace
maintainer: author
homepage: http://code.haskell.org/~malcolm/polyparse/
synopsis: A variety of alternative parser combinator libraries.
description:
    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.
category: Text, Parsing
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain Text.ParserCombinators.Poly.Lazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.Lex Text.Parse
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar Text.Parse.ByteString
    Text.ParserCombinators.Poly.Text
    Text.ParserCombinators.Poly.StateText
abi: 125f9b851136f3e7b631fb1a6bfe805b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/polyparse-1.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/polyparse-1.12
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/polyparse-1.12
hs-libraries: HSpolyparse-1.12-9D0YnY3UMon43vdSjbfwCd
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html: /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
